@@ -39,6 +39,19 @@
  */
 function getFData($format,$data,$meth=NULL) {
   $unique=false;
+  /*
+   * Format : %{[key name][:A][:B][! ou _][~]}
+   *
+   * Extracted fields
+   * - 1 : key name
+   * - 2 : :A
+   * - 3 : A
+   * - 4 : :B
+   * - 5 : B
+   * - 6 : "-"
+   * - 7 : ! or _
+   * - 8 : ~
+   */
   $expr="%[{(]([A-Za-z0-9]+)(\:(-?[0-9])+)?(\:(-?[0-9]+))?(-)?(\!|\_)?(~)?[})]";
   if(!is_array($format)) {
     $format=array($format);
@@ -138,6 +151,16 @@ function _getFData_extractAndModify($data,$ch) {
         $l=$ch[5];
       }
     }
+    else if ($ch[5]==0) {
+      if ($ch[3]<0) {
+        $s=strlen((string)$data)-(-1*$ch[3]);
+        $l=strlen((string)$data);
+      }
+      else {
+        $s=$ch[3];
+	$l=strlen((string)$data);
+      }
+    }
     else {
       $s=0;
       $l=$ch[3];
@@ -145,7 +168,12 @@ function _getFData_extractAndModify($data,$ch) {
     $val=substr((string)$data,$s,$l);
   }
   else {
-    $val=(string)$data;
+    try {
+      $val=strval($data);
+    }
+    catch (Exception $e) {
+      $val=_('[not string value]');
+    }
   }
 
   # Without Accent
@@ -555,4 +583,15 @@ function LSdebugDefined() {
     return $retval;
   }
 
+ /**
+  * Return current date in LDAP format
+  *
+  * @param[in] $mixed Anything (to permit using as generated function)
+  *
+  * @retval string The current date in LDAP format (YYYYMMDDHHMMSSZ)
+  **/
+  function now($mixed=Null) {
+    return date ('YmdHis').'Z';
+  }
+
 ?>
