@@ -1,17 +1,17 @@
-<?php /* Smarty version Smarty-3.1.21-dev, created on 2016-12-14 16:16:13
+<?php /* Smarty version Smarty-3.1.21-dev, created on 2017-08-02 10:07:34
          compiled from "ls:viewSearch.tpl" */ ?>
-<?php /*%%SmartyHeaderCode:11872149665851704da546b6-48539311%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
+<?php /*%%SmartyHeaderCode:20320621185981a466da7384-92389470%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
 $_valid = $_smarty_tpl->decodeProperties(array (
   'file_dependency' => 
   array (
     '7e5e1b40a6897e6cd2a4b75f034a469f40dd849c' => 
     array (
       0 => 'ls:viewSearch.tpl',
-      1 => 1472212472,
+      1 => 1485354558,
       2 => 'ls',
     ),
   ),
-  'nocache_hash' => '11872149665851704da546b6-48539311',
+  'nocache_hash' => '20320621185981a466da7384-92389470',
   'function' => 
   array (
   ),
@@ -34,9 +34,9 @@ $_valid = $_smarty_tpl->decodeProperties(array (
   ),
   'has_nocache_code' => false,
   'version' => 'Smarty-3.1.21-dev',
-  'unifunc' => 'content_5851704db02551_04783770',
+  'unifunc' => 'content_5981a466e52dd2_36437983',
 ),false); /*/%%SmartyHeaderCode%%*/?>
-<?php if ($_valid && !is_callable('content_5851704db02551_04783770')) {function content_5851704db02551_04783770($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
+<?php if ($_valid && !is_callable('content_5981a466e52dd2_36437983')) {function content_5981a466e52dd2_36437983($_smarty_tpl) {?><?php if (!is_callable('smarty_function_html_options')) include '/usr/share/php/smarty3/plugins/function.html_options.php';
 if (!is_callable('smarty_function_cycle')) include '/usr/share/php/smarty3/plugins/function.cycle.php';
 ?><?php echo $_smarty_tpl->getSubTemplate ('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, null, array(), 0);?>
 
@@ -153,7 +153,7 @@ $_smarty_tpl->tpl_vars['item']->_loop = true;
       <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {?>
         <?php  $_smarty_tpl->tpl_vars['conf'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['conf']->_loop = false;
  $_smarty_tpl->tpl_vars['cid'] = new Smarty_Variable;
- $_from = $_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
+ $_from = $_smarty_tpl->tpl_vars['LSsearch']->value->visibleExtraDisplayedColumns; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
 foreach ($_from as $_smarty_tpl->tpl_vars['conf']->key => $_smarty_tpl->tpl_vars['conf']->value) {
 $_smarty_tpl->tpl_vars['conf']->_loop = true;
  $_smarty_tpl->tpl_vars['cid']->value = $_smarty_tpl->tpl_vars['conf']->key;
@@ -202,7 +202,7 @@ $_smarty_tpl->tpl_vars['object']->_loop = true;
         <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {?>
           <?php  $_smarty_tpl->tpl_vars['conf'] = new Smarty_Variable; $_smarty_tpl->tpl_vars['conf']->_loop = false;
  $_smarty_tpl->tpl_vars['cid'] = new Smarty_Variable;
- $_from = $_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
+ $_from = $_smarty_tpl->tpl_vars['LSsearch']->value->visibleExtraDisplayedColumns; if (!is_array($_from) && !is_object($_from)) { settype($_from, 'array');}
 foreach ($_from as $_smarty_tpl->tpl_vars['conf']->key => $_smarty_tpl->tpl_vars['conf']->value) {
 $_smarty_tpl->tpl_vars['conf']->_loop = true;
  $_smarty_tpl->tpl_vars['cid']->value = $_smarty_tpl->tpl_vars['conf']->key;
@@ -231,7 +231,7 @@ if (!$_smarty_tpl->tpl_vars['object']->_loop) {
 ?>
       <tr class='LSobject-list'>
         <td colspan='<?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {
-echo count($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns)+3;
+echo count($_smarty_tpl->tpl_vars['LSsearch']->value->visibleExtraDisplayedColumns)+3;
 } else { ?>3<?php }?>' class='LSobject-list-without-result'>
           <?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->label_no_result;?>
 
